==> jc-1.4.0.tar.gz: soot/grimp/internal/AbstractGrimpFloatBinopExpr.h <==
// public abstract class soot.grimp.internal.AbstractGrimpFloatBinopExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d1552223b1338ef5 soot_grimp_internal_AbstractGrimpFloatBinopExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class b3123b7fa425fe58 soot_jimple_internal_AbstractFloatBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractFloatBinopExpr

#include "soot/jimple/internal/AbstractFloatBinopExpr.h"

#ifndef _JC_soot_grimp_internal_AbstractGrimpFloatBinopExpr_H_
#define _JC_soot_grimp_internal_AbstractGrimpFloatBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_refs	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_nonrefs	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$refs	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$refs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$nonrefs	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object;

typedef const struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vmethods	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtable	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtable;
typedef const struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtype	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method$_init$76c8b23810ae9526(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern jint _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method$toString$19cdbf3266be800b(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method_info$toString$19cdbf3266be800b;

// Virtual methods structure
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vmethods {
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$19cdbf3266be800b)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods	soot_jimple_internal_AbstractFloatBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
};

// Vtype
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$refs {
    _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object {
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtype	*vtype;
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtype _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_AbstractGrimpFloatBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$class_object;

#endif	/* _JC_soot_grimp_internal_AbstractGrimpFloatBinopExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/AbstractGrimpFloatBinopExpr.h <==
// public abstract class soot.grimp.internal.AbstractGrimpFloatBinopExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d1552223b1338ef5 soot_grimp_internal_AbstractGrimpFloatBinopExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class b3123b7fa425fe58 soot_jimple_internal_AbstractFloatBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractFloatBinopExpr

#include "soot/jimple/internal/AbstractFloatBinopExpr.h"

#ifndef _JC_soot_grimp_internal_AbstractGrimpFloatBinopExpr_H_
#define _JC_soot_grimp_internal_AbstractGrimpFloatBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_refs	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_nonrefs	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$refs	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$refs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$nonrefs	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object;

typedef const struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vmethods	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtable	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtable;
typedef const struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtype	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method$_init$76c8b23810ae9526(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method$toString$19cdbf3266be800b(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$method_info$toString$19cdbf3266be800b;

// Virtual methods structure
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vmethods {
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$19cdbf3266be800b)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods	soot_jimple_internal_AbstractFloatBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
};

// Vtype
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$refs {
    _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$object {
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtype	*vtype;
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vtype _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_AbstractGrimpFloatBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$class_object;

#endif	/* _JC_soot_grimp_internal_AbstractGrimpFloatBinopExpr_H_ */
